StatefulServicePartitionDriver

Struct StatefulServicePartitionDriver 

pub struct StatefulServicePartitionDriver { /* private fields */ }
Test driver for a single stateful service replica.

Implementations

Source

impl StatefulServicePartitionDriver

pub fn new() -> Self

pub fn register_service_factory( &mut self, factory: Box<dyn IStatefulServiceFactory>, )

Register a service factory to be used to create replicas. One should register multiple factories to simulate multi node scenarios. Replicas are created in round robin fashion from the registered factories.

Source

impl StatefulServicePartitionDriver

pub fn get_primary_replica_id(&self) -> i64

Get the current primary replica id.

pub fn get_replica( &self, replica_id: i64, ) -> Option<&dyn IStatefulServiceReplica>

Get a replica by id.

pub fn get_replicator(&self, replica_id: i64) -> Option<&dyn IPrimaryReplicator>

Get a replicator by replica id.

pub fn list_replica_ids(&self) -> Vec<i64>

List all replica ids.

Source

impl StatefulServicePartitionDriver

pub async fn create_service_partition( &mut self, desc: &CreateStatefulServicePartitionArg, ) -> Result<()>

Create a stateful service partition with the specified number of replicas. The first replica is the primary. Runs the replica build steps.

pub async fn delete_service_partition(&mut self) -> Result<()>

Delete the service partition.

pub async fn restart_secondary_graceful( &mut self, replica_id: i64, ) -> Result<()>

Restart a secondary replica gracefully.