pub struct HealthDataProducer { /* private fields */ }Expand description
Queries SF and produces health data. User is responsible to implement a consumer to receive the data.
Implementations
Sourceimpl HealthDataProducer
impl HealthDataProducer
pub fn new( fc: FabricClient, interval: Duration, sender: UnboundedSender<ProducerEvent>, ) -> Self
Sourcepub async fn run_loop(&self, token: BoxedCancelToken)
pub async fn run_loop(&self, token: BoxedCancelToken)
Run both the cluster/node loop and the application loop concurrently.
The two loops are independent: a slow application traversal will not delay cluster/node reporting, and vice versa.
Sourcepub async fn run_cluster_node_loop(&self, token: BoxedCancelToken)
pub async fn run_cluster_node_loop(&self, token: BoxedCancelToken)
Run a loop to produce cluster and node health data.
Sourcepub async fn run_application_loop(&self, token: BoxedCancelToken)
pub async fn run_application_loop(&self, token: BoxedCancelToken)
Run a loop to produce application health data.